@@ -99,7 +99,11 @@ NumericVector difLbetakLOGIT_cpp(NumericVector theta,
       NumericVector muikt = muikt_cpp(beta[k], nbeta[k], i, period, A, TCOV, delta, nw, k);
       NumericVector tmp1;
       for (int t = 0; t < period; ++t){
-        tmp1.push_back(pow(1-1/(1+exp(muikt[t])), Y(i,t))*pow(1/(1+exp(muikt[t])), 1-Y(i,t)));
+       if (R_IsNA(Y(i, t)) == FALSE){
+          tmp1.push_back(pow(1-1/(1+exp(muikt[t])), Y(i,t))*pow(1/(1+exp(muikt[t])), 1-Y(i,t)));
+       }else{
+         tmp1.push_back(1);
+       }
       }
       double tmp2 = 0;
       for (int t = 0; t < period; ++t){
@@ -148,7 +152,11 @@ NumericVector difLdeltakLOGIT_cpp(NumericVector theta,
       NumericVector muikt = muikt_cpp(beta[k], nbeta[k], i, period, A, TCOV, delta, nw, k);
       NumericVector tmp1;
       for (int t = 0; t < period; ++t){
-        tmp1.push_back(pow(1-1/(1+exp(muikt[t])), Y(i,t))*pow(1/(1+exp(muikt[t])), 1-Y(i,t)));
+        if (R_IsNA(Y(i, t)) == FALSE){
+          tmp1.push_back(pow(1-1/(1+exp(muikt[t])), Y(i,t))*pow(1/(1+exp(muikt[t])), 1-Y(i,t)));
+        }else{
+          tmp1.push_back(1);
+        }
       }
       double tmp2 = 0;
       for (int t = 0; t < period; ++t){
